#!/bin/bash

STATUSFILE=/var/config/.installer
FILENAME=resiot-basestation-client_3.0-r224_arm926ejste.ipk

grep package $STATUSFILE > /dev/null 2> /dev/null
if [ $? -eq 0 -a ! -x /opt/resiot/resiotbsmon ] ; then
	# statusfile not reset, but gateway has been reflashed, clear file
	rm $STATUSFILE
fi

if [ ! -f $STATUSFILE ] ; then
	touch $STATUSFILE
fi


# Ask the user to select from the function's arguments,
# and assign the selected argument to the variable 'select_result'.
# Exit on EOF or I/O error.  Use the shell's 'select' builtin if available,
# falling back on a less-nice but portable substitute otherwise.
if
  case $BASH_VERSION in
  ?*) : ;;
  '')
    # '; exit' should be redundant, but Dash doesn't properly fail without it.
    (eval 'set --; select x; do break; done; exit') </dev/null 2>/dev/null
  esac
then
  # Do this inside 'eval', as otherwise the shell might exit when parsing it
  # even though it is never executed.
  eval '
    doselect() {
      select select_result
      do
	case $select_result in
	"") echo >&2 "Please enter a number in range." ;;
	?*) break
	esac
      done || exit
    }

    # Work around a bug in bash 1.14.7 and earlier, where $PS3 is sent to stdout.
    case $BASH_VERSION in
    [01].*)
      case `echo 1 | (select x in x; do break; done) 2>/dev/null` in
      ?*) PS3=
      esac
    esac
  '
else
  doselect() {
    # Field width of the prompt numbers.
    select_width=`expr $# : '.*'`

    select_i=

    while :
    do
      case $select_i in
      '')
	select_i=0
	for select_word
	do
	  select_i=`expr $select_i + 1`
	  printf >&2 "%${select_width}d) %s\\n" $select_i "$select_word"
	done ;;
      *[!0-9]*)
	echo >&2 'Please enter a number in range.' ;;
      *)
	if test 1 -le $select_i && test $select_i -le $#; then
	  shift `expr $select_i - 1`
	  select_result=$1
	  break
	fi
	echo >&2 'Please enter a number in range.'
      esac

      # Prompt and read input.
      printf >&2 %s "${PS3-#? }"
      read select_i || exit
    done
  }
fi

# On to the network information
grep network $STATUSFILE > /dev/null 2> /dev/null
if [ $? -ne 0 ] ; then
	echo ""
	echo "NETWORK SETUP"
	echo ""
	echo "Do you want to use DHCP"
	doselect Yes No Skip
	ok=$select_result
	rbt="true"
	case $ok in
		Skip)
			rbt="false"
			echo "Skipping network configuration..."
			;;
		Yes)
			if [ ! -f /var/config/network/interfaces.org ] ; then
				mv /var/config/network/interfaces /etc/network/interfaces.org
			fi
			cat << _EOF_ > /var/config/network/interfaces
# /etc/network/interfaces -- configuration file for ifup(8), ifdown(8)

# The loopback interface
auto lo
iface lo inet loopback

# Wired interface
auto eth0
iface eth0 inet dhcp
#iface eth0 inet static
#address 192.168.2.1
#netmask 255.255.255.0
#gateway 192.168.2.254

# Bridge interface with eth0 (comment out eth0 lines above to use with bridge)
# iface eth0 inet manual
#
# auto br0
# iface br0 inet static
# bridge_ports eth0
# address 192.168.2.1
# netmask 255.255.255.0

# Wifi client
# NOTE: udev rules will bring up wlan0 automatically if a wifi device is detected
# and the wlan0 interface is defined, therefore an "auto wlan0" line is not needed.
# If "auto wlan0" is also specified, startup conflicts may result.
#iface wlan0 inet dhcp
#wpa-conf /var/config/wpa_supplicant.conf
#wpa-driver nl80211
_EOF_
			;;
		No)
			got_it=No
			while [ $got_it != Yes ] ; do
				echo "Please provide network parameters"
				echo -n "IP address: "
				read ip
				echo -n "netmask: "
				read mask
				echo -n "gateway: "
				read gw
				echo -n "DNS IP (use 8.8.8.8 for Google DNS): "
				read dns
				echo
				echo "Supplied information:"
				echo "IP     : $ip"
				echo "Netmask: $mask"
				echo "Gateway: $gw"
				echo "DNS IP : $dns"		
				doselect Yes No
				got_it=$select_result
			done
			cat << _EOF_ > /var/config/network/interfaces
# /etc/network/interfaces -- configuration file for ifup(8), ifdown(8)

# The loopback interface
auto lo
iface lo inet loopback

# Wired interface
auto eth0
iface eth0 inet static
address $ip
netmask $mask
gateway $gw
post-up echo 'nameserver $dns' >/etc/resolv.conf

# Bridge interface with eth0 (comment out eth0 lines above to use with bridge)
# iface eth0 inet manual
#
# auto br0
# iface br0 inet static
# bridge_ports eth0
# address 192.168.2.1
# netmask 255.255.255.0

# Wifi client
# NOTE: udev rules will bring up wlan0 automatically if a wifi device is detected
# and the wlan0 interface is defined, therefore an "auto wlan0" line is not needed.
# If "auto wlan0" is also specified, startup conflicts may result.
#iface wlan0 inet dhcp
#wpa-conf /var/config/wpa_supplicant.conf
#wpa-driver nl80211
_EOF_
	esac
			
	echo "network" >> $STATUSFILE
	if [ $rbt = "true" ] ; then
		echo "Network configuration written"
		echo ""
		echo "The gateway will now shutdown. Remove power once the status led"
		echo "stopped blinking, connect the gateway to the new network and reapply"
		echo "power."
		echo ""
		echo "Press enter to continue"
		read n
		sync;sync;sync
		reboot
		#shutdown -h now
		sleep 600
	fi
fi

# Disable the MultiTech lora server processes
# Do we want to remove the software as well??
grep disable-mtech $STATUSFILE > /dev/null 2> /dev/null
if [ $? -ne 0 ] ; then
	echo "Disable MultiTech packet forwarder"
	/etc/init.d/lora-network-server stop
	cat << _EOF_ > /etc/default/lora-network-server
# set to "yes" or "no" to control starting on boot
ENABLED="no"
_EOF_
	echo "disable-mtech" >> $STATUSFILE
fi

echo "Installing ResIOT Base Station Client"
opkg install $FILENAME

# Everything is in place, start the resiot suite
/etc/init.d/resiotbspf start
/etc/init.d/resiotbstb start
/etc/init.d/resiotbsmon start
/etc/init.d/resiotservice start
/etc/init.d/resiotbsserver start
/etc/init.d/resiotwd start
